# from . import jitsi_chrome

import logging
import os
import warnings
import time

from selenium import webdriver
from selenium.webdriver.common.by import By

from videodrone.utils import get_random_y4m


DRIVER_PATH = os.environ.get('VIDEODRONE_DRIVER', 
                             os.path.join("drivers", 
                                          "chromedriver"))


def get_chrome_browser(y4m=None, headless=True):
    y4m_file = get_random_y4m(path=y4m)
    options = webdriver.ChromeOptions()
    # options.add_argument('')
    if headless:
        options.add_argument('--headless')
    options.add_argument('no-sandbox') # otherwise chromedriver in docker env fails ...
    options.add_argument('disable-infobars')
    options.add_argument('--disable-extensions')
    options.add_argument('--disable-dev-shm-usage')
    options.add_argument('--use-fake-device-for-media-stream')
    options.add_argument('--use-fake-ui-for-media-stream')
    options.add_argument(f'--use-file-for-fake-video-capture={y4m_file}')
    options.add_argument('--disable-gpu')
    browser = webdriver.Chrome(
            executable_path = DRIVER_PATH,
            # desired_capabilities = webdriver.DesiredCapabilities.CHROME,
            options = options,
        )
    return browser




import random
from selenium.common.exceptions import (ElementClickInterceptedException,
                                        NoSuchWindowException)
from selenium.webdriver.common.by import By

from selenium.webdriver.support.ui import WebDriverWait # available since 2.4.0
from selenium.webdriver.support import expected_conditions as EC # available since 2.26.0

from . import *

URL = "https://blue.meet.garr.it"

logger = logging.getLogger(__name__)
warnings.filterwarnings("ignore", category=UserWarning)


def run(room='videodrone', y4m='./y4m', lifetime=360, 
        headless=1, pin=None, **kwargs):
    
    suffix = kwargs.get('id', random.randrange(1000))
    browser = get_chrome_browser(y4m=y4m, headless=headless)
    browser.get(f'{URL}/{room}')
    browser.find_element_by_xpath('//*[@id="room_access_code"]').send_keys(pin)
    browser.find_element_by_xpath('/html/body/div[2]/div/div/div[2]/div[2]/form/div/input[2]').click()
    browser.find_element_by_xpath('//*[@id="_b_giu-1qd-xfs-muy_join_name"]').send_keys(f'videodrone-{suffix}')
    browser.find_element_by_id('room-join').click()
    
    # connection to audio server, this could be lagged
    ui_element = '/html/body/div[2]/div/div/div[1]/div/div/span/button[1]/span[1]'
    element = WebDriverWait(browser, 60).until(EC.presence_of_element_located((By.XPATH, ui_element)))
    element.click()
    ui_element = '/html/body/div[2]/div/div/div[1]/div/span/button[1]/span[1]/i'
    element = WebDriverWait(browser, 60).until(EC.presence_of_element_located((By.XPATH, ui_element)))
    element.click()
    
    # show cam
    time.sleep(5)
    ui_element = "icon-bbb-video_off"
    status_exp = None
    # element_1 = WebDriverWait(browser, 60).until(EC.presence_of_element_located((By.CLASS_NAME, ui_element)))
    element_1 = browser.find_element_by_class_name(ui_element)
    element_2 = browser.find_element_by_xpath('//*[@id="tippy-25"]/span[1]')
    element_3 = browser.find_element_by_id('tippy-25')
    for i in (element_1, element_2, element_3):
        try:
            i.click()
            status_exp = None
        except ElementClickInterceptedException as e:
            status_exp = e
    if status_exp:
        logging.error(status_exp)

    ui_element = "/html/body/div[2]/div/div/div[1]/div/div[3]/div/button[2]/span"
    element = WebDriverWait(browser, 60).until(EC.presence_of_element_located((By.XPATH, ui_element)))
    element.click()
    
    time.sleep(lifetime)
    # leave the room
    browser.find_element_by_xpath('//*[@id="tippy-3"]/span[1]').click()
    browser.find_element_by_xpath('//*[@id="app"]/main/section/div[1]/header/div/div[1]/div[3]/div/div/div/ul/li[8]').click()
    try:
        browser.close()
    except NoSuchWindowException as e:
        logging.warning('Browser already closed.')
    logger.info('Drone say goodbye ... Destroyed.')



from selenium.common.exceptions import NoSuchWindowException
from selenium.webdriver.common.by import By

from . import *

URL = "https://lepida1.iorestoacasa.work"

logger = logging.getLogger(__name__)
warnings.filterwarnings("ignore", category=UserWarning)


def run(room, y4m, lifetime=360, headless=1, **kwargs):
    browser = get_chrome_browser(y4m=y4m, headless=headless)
    browser.get(f'{URL}/{room}')
    browser.find_element_by_xpath('/html/body/div[2]/div[3]/div/div[3]/button[2]').click()
    # browser.find_element(By.XPATH('/html/body/div[2]/div[3]/div/div[3]/button[2]')).click()
    time.sleep(lifetime)
    # leave the room
    browser.find_element_by_xpath('/html/body/div[1]/div/header/div/button/span[1]').click()
    # browser.find_element(By.XPATH('/html/body/div[1]/div/header/div/button/span[1]')).click()
    try:
        browser.close()
    except NoSuchWindowException as e:
        logging.warning('Browser already closed.')
    logger.info('Drone say goodbye ... Destroyed.')



import logging

from selenium.common.exceptions import NoSuchWindowException
from . import *

logger = logging.getLogger(__name__)


URL = "https://meet.jit.si"
warnings.filterwarnings("ignore", category=UserWarning)


def run(room, y4m, lifetime=360, headless=1, **kwargs):
    browser = get_chrome_browser(y4m=y4m, headless=headless)
    browser.get(f'{URL}/{room}')
    # Deprecation Warning
    browser.find_element_by_class_name('action-btn').click()
    # browser.find_element(value='action-btn', by=By.CLASS_NAME)
    time.sleep(lifetime)
    # leave the room
    browser.find_element_by_class_name('toolbox-button').click()
    try:
        browser.close()
    except NoSuchWindowException as e:
        logging.warning('Browser already closed.')
    logger.info('Drone say goodbye ... Destroyed.')



import random

from selenium.common.exceptions import NoSuchWindowException
from selenium.webdriver.common.by import By

from . import *

URL = "https://web.vconf.garr.it/webapp/conference"

logger = logging.getLogger(__name__)
warnings.filterwarnings("ignore", category=UserWarning)


def run(room='videodrone', y4m='./y4m', lifetime=360, 
        headless=1, pin=None, **kwargs):
    
    suffix = kwargs.get('id', random.randrange(1000))
    browser = get_chrome_browser(y4m=y4m, headless=headless)
    browser.get(f'{URL}/{room}')
    
    time.sleep(3)
    browser.find_element_by_id('display-name-dialog-input').send_keys(f'videodrone-{suffix}')
    time.sleep(1)
    browser.find_element_by_id('display-name-dialog-ok').click()
    
    time.sleep(3)
    browser.find_element_by_id('dialog-pin-input').send_keys(pin)
    time.sleep(1)
    browser.find_element_by_id('conference-pin-btn').click()
    
    time.sleep(lifetime)
    # leave the room
    try:
        browser.close()
    except NoSuchWindowException as e:
        logging.warning('Browser already closed.')
    logger.info('Drone say goodbye ... Destroyed.')



import glob
import logging
import random

logger = logging.getLogger(__name__)


def get_random_y4m(path='/tmp/y4ms'):
    y4ms = [i for i in glob.iglob(f'{path}/*y4m')]
    if not y4ms: 
        logger.warning(f'WARNING: y4ms folder is empty: {path}')
    return random.choices(y4ms)[0]



import logging

from . import *

URL = "https://open.meet.garr.it/"

logger = logging.getLogger(__name__)
warnings.filterwarnings("ignore", category=UserWarning)


def run(room, y4m, lifetime=360, headless=1, **kwargs):
    browser = get_chrome_browser(y4m=y4m, headless=headless)
    browser.get(f'{URL}/{room}')
    time.sleep(lifetime)
    # leave the room
    try:
        browser.close()
    except NoSuchWindowException as e:
        logging.warning('Browser already closed.')
    logger.info('Drone say goodbye ... Destroyed.')



from setuptools import setup, Extension, find_packages

def readme():
    with open('README.md') as f:
        return f.read()

DESC = "WebRTC python unit tests inspired to '80s"

setup(name='videodrone',
      version='0.9.6',
      description=DESC,
      long_description=readme(),
      long_description_content_type='text/markdown',
      classifiers=['Development Status :: 5 - Production/Stable',
                   'License :: OSI Approved :: Apache Software License',
                   "Programming Language :: Python :: 3.6",
                   "Programming Language :: Python :: 3.7",
                   "Programming Language :: Python :: 3.8"],
      url='https://github.com/peppelinux/airdrone',
      author='Giuseppe De Marco',
      author_email='giuseppe.demarco@unical.it',
      license="Apache 2.0",
      packages=['videodrone', 'videodrone.drones'],
      scripts=['videodrone'],
      package_dir={"": "src"},
      install_requires=[
            'selenium>=3.0.0'
        ],
     )
